//  smartGallery v2.1 by Vel Forrester  -  requires smartGallery.js, smartGallery.css  -  www.velforrester.com
//---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
//  use class sg-galleryImage on a set of images contained in an element with class sg-gallery to enable a lightbox style gallery on click. ex:
//  <div id="any-gallery-id" class="sg-gallery">
//		<img id="any-image-id-1" class="sg-galleryImage" src="/path/to/image"/>
//		<img id="any-image-id-2" class="sg-galleryImage" src="/path/to/image"/>
//		...
//  </div>
//---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
//  use class sg-zoomImage on a single image to enable a lightbox style image zoom on click. ex:
//  <img id="any-image-id" class="sg-zoomImage" src="/path/to/image">
//---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
//---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
//  add click event to all elements with class sg-galleryImage
var smartGallery = {};
let galleryImages = document.querySelectorAll('.sg-galleryImage');
for(let i = 0; i < galleryImages.length; i++){
	galleryImages[i].addEventListener('click', function(event){
		//  set initial lightbox variables
		let galleryId = event.target.parentNode.getAttribute('id');
		let currentImageId = event.target.getAttribute('id'); 
		let currentImageSrc = event.target.getAttribute('src');
		// create smartGallery object and load lightbox
		smartGallery = new smartGalleryInstance(galleryId,currentImageId,currentImageSrc);
		smartGallery.loadGalleryLightbox();
	});
}
//  create smartGallery object instance
class smartGalleryInstance {
	constructor(galleryId,currentImageId,currentImageSrc){
		this.galleryId = galleryId;
		this.currentImageId = currentImageId;
		this.currentImagePath = currentImageSrc;
		this.imageIds = this.getImageIds(this.id);
		this.imagePaths = this.getImagePaths(this.id);
		this.nextImageId = this.getNextImageId(this.id);
		this.previousImageId = this.getPreviousImageId(this.id);
	}
	//  create array containing ids of all images in gallery
	getImageIds(){
		let galleryImages = document.querySelectorAll('.sg-galleryImage');
		let imageIds = [];
		for(let i = 0; i < galleryImages.length; i++){
			if(this.galleryId == galleryImages[i].parentNode.getAttribute('id')){
				imageIds.push(galleryImages[i].getAttribute('id'));
			}
		}
		return imageIds;
	}
	//  create array containing src of all images in gallery
	getImagePaths(){
		let galleryImages = document.querySelectorAll('.sg-galleryImage');
		let imagePaths = [];
		for(let i = 0; i < galleryImages.length; i++){
			if(this.galleryId == galleryImages[i].parentNode.getAttribute('id')){
				imagePaths.push(galleryImages[i].getAttribute('src'));
			}
		}
		return imagePaths;
	}
	//  calculate next image id based on nodes in parent gallery
	getNextImageId(){
		var currentImage = document.getElementById(this.currentImageId);
		if(currentImage.nextElementSibling == 'undefined' || currentImage.nextElementSibling == undefined){
			var nextImageId = document.getElementById(this.galleryId).firstElementChild.getAttribute('id');
		}else{
			var nextImageId = currentImage.nextElementSibling.getAttribute('id');
		}
		return nextImageId;
	}
	// calculate previous image id based on nodes in parent gallery
	getPreviousImageId(){
		var currentImage = document.getElementById(this.currentImageId);
		if(currentImage.previousElementSibling == 'undefined' || currentImage.previousElementSibling == undefined){
			var previousImageId = document.getElementById(this.galleryId).lastElementChild.getAttribute('id');
		}else{
			var previousImageId = currentImage.previousElementSibling.getAttribute('id');
		}
		return previousImageId;
	}
	loadGalleryLightbox(){
		//  build gallery lightbox
		let previousImageId = "'" + this.previousImageId + "'";
		let nextImageId = "'" + this.nextImageId + "'";
		let html = '<img id="sg-lightboxClose" src="graphics/close.png" onClick="smartGallery.closeGalleryLightBox();" />';
		html += '<div id="sg-lightboxImgCont">';
		html += '<img id="sg-previous" class="sg-prevImg" src="graphics/prev.png" onClick="smartGallery.loadSelectedImage(' + previousImageId + ');" />';
		html += '<img id="sg-swipeImage" class="sg-lightboxImage" src="' + this.currentImagePath + '" />';
		html += '<img id ="sg-next" class="sg-nextImg" src="graphics/next.png" onClick="smartGallery.loadSelectedImage(' + nextImageId + ');" />';
		html += '<div id="sg-galleryCarousel">';
		html += '<div id="sg-openGalleryCarousel" class="sg-center">&#9634;&#9634;&#9634;&#9634;</div>';
		html += '<div id="sg-galleryCarouselImgCont">';
		for (let i = 0; i < this.imageIds.length; i++){
			html += '<img id="' + this.imageIds[i] + '" class="sg-carouselImg" src="' + this.imagePaths[i] + '"/>';
		};
		html += '</div></div></div>';
		//  load gallery lightbox - animated
		let lightbox = document.getElementById('sg-lightbox');
		lightbox.innerHTML = html;
		lightbox.style.display = 'flex';
		setTimeout(() => {
			lightbox.style.opacity = 1;
		}, 50)
		//  set carousel click events
		let carouselImages = document.querySelectorAll('.sg-carouselImg');
		for(let i = 0; i < carouselImages.length; i++){
			carouselImages[i].addEventListener('click', function(event){
				let imageId = event.target.getAttribute('id');
				smartGallery.loadSelectedImage(imageId);
			});
		}
		//  set swipe events, left loads next image, right loads previous image
		let swipeImage = document.getElementById('sg-swipeImage');
		var touchStartX;
		var touchEndX;
		swipeImage.addEventListener('touchstart', function(event){
			touchStartX = event.changedTouches[0].screenX;
		}, false);
		swipeImage.addEventListener('touchend', function(event){
			touchEndX = event.changedTouches[0].screenX;
			if(touchStartX < touchEndX && touchStartX - touchEndX < -30){
				smartGallery.loadSelectedImage(smartGallery.previousImageId);
			}
			if(touchStartX > touchEndX && touchStartX - touchEndX > 30){
				smartGallery.loadSelectedImage(smartGallery.nextImageId);
			}
		}, false);
		
	}
	//  reload lightbox elements based on new current image
	loadSelectedImage(id){
		let selectedImage = document.getElementById(id);
		this.currentImageId = id;
		this.currentImagePath = selectedImage.getAttribute('src');;
		this.nextImageId = this.getNextImageId(this.id);
		this.previousImageId = this.getPreviousImageId(this.id);
		let image = document.getElementById('sg-swipeImage');
		let previous = document.getElementById('sg-previous');
		let next = document.getElementById('sg-next');
		image.src = this.currentImagePath;
		previous.setAttribute('onclick', 'smartGallery.loadSelectedImage("' + this.previousImageId + '");');
		next.setAttribute('onclick', 'smartGallery.loadSelectedImage("' + this.nextImageId + '");');
	}
	// close gallery lightbox and remove html - animated
	closeGalleryLightBox(){
		let lightbox = document.getElementById('sg-lightbox');
		lightbox.style.opacity = 0;
		setTimeout(() => {
			lightbox.style.display = 'none';
			lightbox.innerHtml = '';
		}, 500)
	}
}
//---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// smart zoom
//---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
var smartZoom = {};
//  add click event to all elements with class sg-zoomImage
let zoomImages = document.querySelectorAll('.sg-zoomImage');
for(let i = 0; i < zoomImages.length; i++){
	zoomImages[i].addEventListener('click', function(event){
		//  set initial lightbox variables
		let imageId = event.target.getAttribute('id'); 
		let imageSrc = event.target.getAttribute('src');
		// create smartZoom object and load lightbox
		smartZoom = new smartZoomInstance(imageId,imageSrc);
		smartZoom.loadZoomLightbox();
	});
}
//  create smartZoom object instance
class smartZoomInstance {
	constructor(imageId,imageSrc){
		this.imageId = imageId;
		this.imageSrc = imageSrc;
	}
	loadZoomLightbox(){
		//  build zoom lightbox
		let html = '<img id="sg-lightboxClose" src="graphics/close.png" onClick="smartZoom.closeZoomLightBox();" />';
		html += '<div id="sg-lightboxImgCont">';
		html += '<img id="sg-zoomImage" class="sg-lightboxImage" src="' + this.imageSrc + '" />';
		html += '</div>';
		//  load zoom lightbox - animated
		let lightbox = document.getElementById('sg-lightbox');
		lightbox.innerHTML = html;
		lightbox.style.display = 'flex';
		setTimeout(() => {
			lightbox.style.opacity = 1;
		}, 50)
	}
	// close zoom lightbox and remove html - animated
	closeZoomLightBox(){
		let lightbox = document.getElementById('sg-lightbox');
		lightbox.style.opacity = 0;
		setTimeout(() => {
			lightbox.style.display = 'none';
			lightbox.innerHtml = '';
		}, 500)
	}
}